@@ -41,7 +41,7 @@
 #include "kmclipm_priv_functions.h"
 #include "kmclipm_priv_error.h"
 
-cpl_msg_severity my_level= CPL_MSG_INFO;
+cpl_msg_severity my_level= CPL_MSG_WARNING;
 
 /*------------------------------------------------------------------------------
  *              Implementation
@@ -1086,7 +1086,7 @@ int main()
      *  (or export CPL_MSG_LEVEL=warning)
      */
 
-    cpl_test_init("<kmos-spark@mpe.mpg.de>", my_level);
+    cpl_test_init("<usd-help@eso.org>", my_level);
 
     char *my_path = cpl_sprintf("%s/test_data", ".");
     mkdir(my_path, 0777);
