@@ -396,10 +396,6 @@ cpl_table*         kmo_dfs_load_table(cpl_frameset *frameset,
                                        int noise);
 
 /* ---------------------- save -------------------------------------------- */
-char*              kmo_dfs_create_filename(const char *path,
-                                       const char *category,
-                                       const char *suffix);
-
 char*              kmo_dfs_get_suffix(const cpl_frame *frame,
                                        int grating,
                                        int angle);
