@@ -467,7 +467,7 @@ static int kmo_illumination_flat(cpl_parameterlist *parlist, cpl_frameset *frame
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Exactly one WAVE_BAND frame is required!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_illumination_flat") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
