@@ -1,5 +1,4 @@
-/* $Id: kmo_sky_mask.c,v 1.9 2013-08-02 15:46:38 aagudo Exp $
- *
+/*
  * This file is part of the KMOS Pipeline
  * Copyright (C) 2002,2003 European Southern Observatory
  *
@@ -18,13 +17,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/*
- * $Author: aagudo $
- * $Date: 2013-08-02 15:46:38 $
- * $Revision: 1.9 $
- * $Name: not supported by cvs2svn $
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -146,7 +138,7 @@ int cpl_plugin_get_info(cpl_pluginlist *list)
                         "pixels can be considered as sky.",
                         kmo_sky_mask_description,
                         "Alex Agudo Berbel",
-                        "kmos-spark@mpe.mpg.de",
+                        "usd-help@eso.org",
                         kmos_get_license(),
                         kmo_sky_mask_create,
                         kmo_sky_mask_exec,
@@ -202,7 +194,7 @@ static int kmo_sky_mask_create(cpl_plugin *plugin)
     cpl_parameter_disable(p, CPL_PARAMETER_MODE_ENV);
     cpl_parameterlist_append(recipe->parameters, p);
 
-    return kmo_combine_pars_create(recipe->parameters,
+    return kmos_combine_pars_create(recipe->parameters,
                                    "kmos.kmo_sky_mask",
                                    DEF_REJ_METHOD,
                                    TRUE);
@@ -303,7 +295,7 @@ static int kmo_sky_mask(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        CPL_ERROR_NULL_INPUT,
                        "Exactly one data cube must be provided!");
 
-        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset, "kmo_sky_mask") == 1,
+        KMO_TRY_ASSURE(kmo_dfs_set_groups(frameset) == 1,
                        CPL_ERROR_ILLEGAL_INPUT,
                        "Cannot identify RAW and CALIB frames!");
 
@@ -333,7 +325,7 @@ static int kmo_sky_mask(cpl_parameterlist *parlist, cpl_frameset *frameset)
                        "fraction must be between 0.0 and 1.0!!");
 
         KMO_TRY_EXIT_IF_ERROR(
-            kmo_combine_pars_load(parlist,
+            kmos_combine_pars_load(parlist,
                                   "kmos.kmo_sky_mask",
                                   &cmethod,
                                   &cpos_rej,
@@ -341,7 +333,7 @@ static int kmo_sky_mask(cpl_parameterlist *parlist, cpl_frameset *frameset)
                                   &citer,
                                   NULL,
                                   NULL,
-                                  FALSE));
+                                  TRUE));
 
         cpl_msg_info("", "-------------------------------------------");
 
@@ -398,22 +390,24 @@ static int kmo_sky_mask(cpl_parameterlist *parlist, cpl_frameset *frameset)
                     data_in = kmo_dfs_load_cube(frameset, "0", devnr, FALSE));
 
                 if (ranges != NULL) {
-                    ifu_crpix = cpl_propertylist_get_double(sub_header_data,
-                                                            CRPIX3);
+                    ifu_crpix = cpl_propertylist_get_double(sub_header_data, CRPIX3);
                     KMO_TRY_CHECK_ERROR_STATE_MSG(
                                    "CRPIX3 keyword in FITS-header is missing!");
 
-                    ifu_crval = cpl_propertylist_get_double(sub_header_data,
-                                                            CRVAL3);
+                    ifu_crval = cpl_propertylist_get_double(sub_header_data, CRVAL3);
                     KMO_TRY_CHECK_ERROR_STATE_MSG(
                                    "CRVAL3 keyword in FITS-header is missing!");
 
-                    ifu_cdelt = cpl_propertylist_get_double(sub_header_data,
-                                                            CDELT3);
+                    ifu_cdelt = cpl_propertylist_get_double(sub_header_data, CDELT3);
                     KMO_TRY_CHECK_ERROR_STATE_MSG(
                                    "CDELT3 keyword in FITS-header is missing!");
                 }
 
+                cpl_propertylist_erase(sub_header_data, CRPIX3);
+                cpl_propertylist_erase(sub_header_data, CRVAL3);
+                cpl_propertylist_erase(sub_header_data, CDELT3);
+                cpl_propertylist_erase(sub_header_data, CTYPE3);
+
                 // calc mode and noise
                 KMO_TRY_EXIT_IF_NULL(
                     data_out = kmo_calc_sky_mask(data_in,
