@@ -513,7 +513,7 @@ static int kmos_illumination(
     }
 
     /* Identify the RAW and CALIB frames in the input frameset */
-    if (kmo_dfs_set_groups(frameset, "kmos_illumination") != 1) {
+    if (kmo_dfs_set_groups(frameset) != 1) {
         cpl_msg_error(__func__, "Cannot identify RAW and CALIB frames") ;
         cpl_error_set(__func__, CPL_ERROR_ILLEGAL_INPUT) ;
         return -1 ;
